from http_pyparser.parser import HTTPData
from wsblib.request import RequestData

from .mathiz import Mathiz

request = RequestData(HTTPData(), ())

__version__ = '0.3.1'
